OC.L10N.register(
    "settings",
    {
    "Private" : "Einka",
    "Local" : "Staðvært",
    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
    "Published" : "Útgefið",
    "Verify" : "Sannreyna",
    "Verifying …" : "Sannreyni …",
    "Unable to change password" : "Ekki tókst að breyta lykilorði",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Svo-svo lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Groups" : "Hópar",
    "Group list is empty" : "Listi yfir hópa er tómur",
    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
    "{actor} added you to group {group}" : "{actor} bætti þér við hópinn {group}",
    "You added {user} to group {group}" : "Þú bættir {user} við hópinn {group}",
    "{actor} added {user} to group {group}" : "{actor} bætti {user} við hópinn {group}",
    "An administrator added you to group {group}" : "Stjórnandi bætti þér við hópinn {group}",
    "An administrator added {user} to group {group}" : "Stjórnandi bætti {user} við hópinn {group}",
    "{actor} removed you from group {group}" : "{actor} fjarlægði þig úr hópnum {group}",
    "You removed {user} from group {group}" : "Þú fjarlægðir {user} úr hópnum {group}",
    "{actor} removed {user} from group {group}" : "{actor} fjarlægði {user} úr hópnum {group}",
    "An administrator removed you from group {group}" : "Stjórnandi fjarlægði þig úr hópnum {group}",
    "An administrator removed {user} from group {group}" : "Stjórnandi fjarlægði {user} úr hópnum {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>Hópaheimildum</strong> þínum var breytt",
    "{actor} changed your password" : "{actor} breytti lykilorðinu þínu",
    "You changed your password" : "Þú breyttir lykilorðinu þínu",
    "Your password was reset by an administrator" : "Kerfisstjóri breytti lykilorðinu þínu",
    "Your password was reset" : "Lykilorðið þitt hefur verið endursett",
    "{actor} changed your email address" : "{actor} breytti tölvupóstfanginu þínu",
    "You changed your email address" : "Þú breyttir tölvupóstfanginu þínu",
    "Your email address was changed by an administrator" : "Kerfisstjóri breytti tölvupóstfanginu þínu",
    "You created an app password for a session named \"{token}\"" : "Þú bjóst til forritslykilorð fyrir setu sem kallast \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Stjórnandi bjó til forritslykilorð fyrir setu sem kallast \"{token}\"",
    "You deleted app password \"{token}\"" : "Þú eyddir forritslykilorðinu \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Þú endurnefndir forritslykilorðið \"{token}\" sem \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Þú veittir forritslykilorðinu \"{token}\" aðgang að skráakerfinu",
    "You revoked filesystem access from app password \"{token}\"" : "Þú afturkallaðir aðgang að skráakerfinu á forritslykilorðinu \"{token}\"",
    "Security" : "Öryggi",
    "You successfully logged in using two-factor authentication (%1$s)" : "Þér tókst að skrá þig inn með tveggja-þrepa auðkenningu (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Innskráning með tveggja-þrepa auðkenningu mistókst (%1$s)",
    "Remote wipe was started on %1$s" : "Fjartengd útþurrkun var hafin á %1$s",
    "Remote wipe has finished on %1$s" : "Fjartengdri útþurrkun er lokið á %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Breyting hefur orðið á <strong>lykilorði</strong> eða <strong>tölvupóstfangi</strong> þínu",
    "Settings" : "Stillingar",
    "Could not remove app." : "Gat ekki fjarlægt forrit.",
    "Could not update app." : "Gat ekki uppfært forrit.",
    "Wrong password" : "Rangt lykilorð",
    "Unable to change personal password" : "Ekki tókst að breyta persónulegu lykilorði",
    "Saved" : "Vistað",
    "Unable to change password. Password too long." : "Ekki tókst að breyta lykilorði. Lykilorðið er of langt.",
    "Authentication error" : "Villa við auðkenningu",
    "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
    "Administrator documentation" : "Hjálparskjöl stjórnanda",
    "User documentation" : "Hjálparskjöl notenda",
    "Nextcloud help overview" : "Efnisyfirlit Nextcloud-hjálpar",
    "Invalid SMTP password." : "Ógilt SMTP-lykilorð",
    "Email setting test" : "Prófa tölvupóststillingar",
    "Well done, %s!" : "Vel gert, %s!",
    "If you received this email, the email configuration seems to be correct." : "Fyrst að þú fékkst þennan tölvupóst, þá lítur út fyrir að tölvupóstuppsetningin sé í lagi.",
    "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
    "Invalid account" : "Ógildur aðgangur",
    "Invalid mail address" : "Ógilt tölvupóstfang",
    "Settings saved" : "Stillingar vistaðar",
    "Unable to change full name" : "Get ekki breytt fullu nafni",
    "Unable to change email address" : "Get ekki breytt tölvupóstfangi",
    "Unable to set invalid phone number" : "Get ekki sett ógilt símanúmer",
    "Unable to set invalid website" : "Get ekki sett ógilt vefsvæði",
    "Some account data was invalid" : "Sum gögn aðgangsins voru ógild",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Til að sannprófa Twitter-aðganginn þinn, sendu þá eftirfarandi tíst á Twitter (gakktu úr skugga um að skeytinu sé ekki skipt í línur):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Til að sannprófa vefsvæðið þitt, vistaðu eftirfarandi efni á vefrótinni þinni (web-root) á '.well-known/CloudIdVerificationCode.txt' (gakktu úr skugga um að allur textinn sé í einni línu):",
    "%1$s changed your password on %2$s." : "%1$s breytti lykilorðinu þínu á %2$s.",
    "Your password on %s was changed." : "Lykilorðinu þínu á %s hefur verið breytt.",
    "Your password on %s was reset by an administrator." : "Kerfisstjóri breytti lykilorðinu þínu á %s.",
    "Your password on %s was reset." : "Lykilorðinu þínu á %s hefur verið breytt.",
    "Password for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist %2$s",
    "Password changed for %s" : "Lykilorð breyttist fyrir %s",
    "If you did not request this, please contact an administrator." : "Ef þú baðst ekki um þetta, hafðu þá samband við kerfisstjóra.",
    "Your email address on %s was changed." : "Tölvupóstfanginu þínu á %s var breytt.",
    "Your email address on %s was changed by an administrator." : "Kerfisstjóri breytti tölvupóstfanginu þínu á %s.",
    "Email address for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist þann %2$s",
    "Email address changed for %s" : "Tölvupóstfang breyttist fyrir %s",
    "The new email address is %s" : "Nýja tölvupóstfangið er %s",
    "Your %s account was created" : "%s notandaaðgangurinn þinn var búinn til",
    "Welcome aboard" : "Velkomin um borð",
    "Welcome aboard %s" : "Velkomin um borð %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Velkomin(n) í %s aðganginn þinn; þú getur bætt við, varið og deilt gögnunum þínum.",
    "Set your password" : "Stilltu lykilorðið þitt",
    "Go to %s" : "Farðu í %s",
    "Install Client" : "Setja upp biðlaraforrit",
    "Apps" : "Forrit",
    "Personal" : "Einka",
    "Administration" : "Stjórnun",
    "Users" : "Notendur",
    "Additional settings" : "Valfrjálsar stillingar",
    "Artificial Intelligence" : "Gervigreind",
    "Administration privileges" : "Kerfisstjórnunarheimildir",
    "Groupware" : "Hópvinnukerfi",
    "Overview" : "Yfirlit",
    "Basic settings" : "Grunnstillingar",
    "Sharing" : "Deiling",
    "Availability" : "Aðgengileiki",
    "Calendar" : "Dagatal",
    "Personal info" : "Persónulegar upplýsingar",
    "Mobile & desktop" : "Farsímar og borðtölvur",
    "Email server" : "Póstþjónn",
    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
    "Background jobs" : "Verk í bakgrunni",
    "Unlimited" : "ótakmörkuðu",
    "Verifying" : "Sannreyni",
    "Your remote address could not be determined." : "Ekki var hægt að ákvarða fjartengda vistfangið þitt.",
    "Database missing columns" : "Gagnagrunn vantar dálka",
    "Missing optional column \"%s\" in table \"%s\"." : "Vantar valkvæða dálkinn \"%s\" í töflunni \"%s\".",
    "Database missing indices" : "Gagnagrunn vantar vísa",
    "Missing optional index \"%s\" in table \"%s\"." : "Vantar valkvæða vísinn \"s\" í töflunni \"%s\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "Database missing primary keys" : "Gagnagrunn vantar aðallykla",
    "Missing primary key on table \"%s\"." : "Vantar aðallykilinn í töflunni \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Gagnagrunninn vantar nokkra aðallykla (primary keys). Vegna þess að það að bæta aðallyklum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-primary-keys\" væri hægt að bæta inn þessum aðallyklum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum aðallyklum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "Default phone region" : "Sjálfgefið svæði símaþjónustu",
    "Email test" : "Prófa tölvupóststillingar",
    "Email test was successfully sent" : "Það tókst að senda tölvupóstprófun",
    "File locking" : "Skráalæsing",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Gagnagrunnurinn er notaður fyrir færslulæsingu skráa. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng. Þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt fyrir Nextcloud.",
    "Your IP address was resolved as %s" : "IP-vistfangið þitt var leyst sem %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng, eða að þú ert að tengjast Nextcloud frá treystum milliþjóni. Ef ekki, þá er þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt fyrir Nextcloud.",
    "Internet connectivity" : "Tenging við internet",
    "Internet connectivity is disabled in configuration file." : "Tenging við internet er gerð óvirk í stillingaskrá.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Þessi þjónn er ekki með virka internettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
    "Old server-side-encryption" : "Eldri gerð dulritunar á þjóni",
    "Disabled" : "Óvirkt",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Eldri gerð dulritunar á þjóni er virk. Við mælum með því að hún sé gerð óvirk.",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Ekkert skyndiminni (cache) hefur verið stillt Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt.",
    "Configured" : "Stillt",
    "PHP default charset" : "Sjálfgefin stafatafla PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP-stillingarofinn \"default_charset\" ætti að vera UTF-8",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
    "Freetype" : "Freetype",
    "Supported" : "Stutt",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "PHP memory limit" : "Minnismörk PHP",
    "The PHP memory limit is below the recommended value of %s." : "Minnismörk PHP eru lægri en gildið sem mælt er með; %s.",
    "PHP modules" : "PHP-einingar",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Í þetta kerfistilvik vantar ýmsar nauðsynlegar PHP-einingar. Mælt er eindregið með að setja þær upp: %s.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. Fyrir betri afköst mælum við með að því sé hlaðið inn í PHP-uppsetninguna þína.",
    "PHP version" : "PHP-útgáfa",
    "You are currently running PHP %s." : "Þú ert núna að keyra PHP %s.",
    "Random generator" : "Slembigjafi",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Enginn hentugur gagnagjafi fyrir handahófsreikning fannst fyrir PHP, sem er mjög óráðlegt af öryggisástæðum.",
    "Secure" : "Öruggt",
    "Configuration file access rights" : "Aðgangsheimildir að stillingaskrá",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "Nextcloud configuration file is writable" : "Stillingaskrá Nextcloud er ritanleg",
    "Database version" : "Útgáfa gagnagrunns",
    "Unknown database platform" : "Óþekkt gagnagrunnskerfi",
    "Architecture" : "Tölvuhögun",
    "64-bit" : "64-bita",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    "Profile information" : "Persónuupplýsingar",
    "Nextcloud settings" : "Stillingar Nextcloud",
    "Machine translation" : "Vélræn þýðing",
    "Speech-To-Text" : "Tal-í-texta",
    "Image generation" : "Gerð mynda",
    "Text processing" : "Textavinnsla",
    "Task:" : "Verk:",
    "None" : "Ekkert",
    "Unable to modify setting" : "Ekki gekk að breyta stillingu",
    "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Allow sharing with groups" : "Leyfa deilingu með hópum",
    "Restrict users to only share with users in their groups" : "Takmarka notendur við að deila með notendum í þeirra eigin hópum",
    "Allow users to share via link and emails" : "Leyfa notendum að deila með tenglum og tölvupósti",
    "Allow public uploads" : "Leyfa opinberar innsendingar",
    "Always ask for a password" : "Alltaf biðja um lykilorð",
    "Enforce password protection" : "Krefjast verndunar með aðgangsorði",
    "Exclude groups from password requirements" : "Undanskilja hópa frá kröfum um lykilorð",
    "Exclude groups from creating link shares" : "Undanskilja hópa frá því að búa til sameignartengla",
    "Exclude groups from sharing" : "Undanskilja hópa frá því að deila",
    "Groups excluded from sharing" : "Hópar undanskildir frá því að deila",
    "These groups will still be able to receive shares, but not to initiate them." : "Þessir hópar munu samt geta tekið við deildum sameignum, en ekki geta útbúið þær.",
    "Set default expiration date for shares" : "Setja sjálfgefinn gildistíma fyrir sameignir",
    "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
    "Default expiration time of new shares in days" : "Sjálfgefinn gildistími fyrir nýjar sameignir í dögum",
    "Expire shares after x days" : "Sameignir renna út eftir x daga",
    "Set default expiration date for shares to other servers" : "Setja sjálfgefinn gildistíma fyrir sameignir til annarra netþjóna",
    "Enforce expiration date for remote shares" : "Krefjast dagsetningar á gildistíma fjartengdra sameigna",
    "Default expiration time of remote shares in days" : "Sjálfgefinn gildistími fyrir fjartengdar sameignir í dögum",
    "Expire remote shares after x days" : "Fjartengdar sameignir renna út eftir x daga",
    "Set default expiration date for shares via link or mail" : "Setja sjálfgefinn gildistíma fyrir sameignir sem deilt er með tengli eða tölvupósti",
    "Default expiration time of shares in days" : "Sjálfgefinn gildistími fyrir sameignir í dögum",
    "Privacy settings for sharing" : "Stillingar á friðhelgi deilingar",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Leyfa sjálfklárun notandanafns á notendum innan sömu hópa og takmarka kerfisnafnaskrár við notendur innan sömu hópa",
    "Allow username autocompletion to users based on phone number integration" : "Leyfa sjálfklárun notandanafns á notendum byggt á samþættingu símanúmera",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Birta fyrirvara á opinberu innsendingasíðunni (birtist einungis þegar listi yfir skrár er falinn)",
    "Disclaimer text" : "Texti fyrirvara",
    "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
    "Default share permissions" : "Sjálfgefnar aðgangsheimildir fyrir deilingu",
    "Changed disclaimer text" : "Breyttur texti fyrirvara",
    "Deleted disclaimer text" : "Eyddi texta fyrirvara",
    "Could not set disclaimer text" : "Gat ekki stillt texta fyrirvara",
    "Two-Factor Authentication" : "Tveggja-þrepa auðkenning",
    "Enforce two-factor authentication" : "Þvinga fram tveggja-þrepa auðkenningu",
    "Limit to groups" : "Takmarka við hópa",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Hægt er að þvinga fram tveggja-þátta auðkenningu fyrir einungis ákveðna hópa.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tveggja-þrepa auðkenning er þvinguð fram fyrir alla meðlimi eftirfarandi hópa.",
    "Enforced groups" : "Þvingaðir hópar",
    "Two-factor authentication is not enforced for members of the following groups." : "Tveggja-þrepa auðkenning er ekki þvinguð fram fyrir meðlimi eftirfarandi hópa.",
    "Excluded groups" : "Útilokaðir hópar",
    "Save changes" : "Vista breytingar",
    "All" : "Allt",
    "Limit app usage to groups" : "Takmarka notkun forrits við tiltekna hópa",
    "No results" : "Engar niðurstöður",
    "Update to {version}" : "Uppfæra í {version}",
    "Remove" : "Fjarlægja",
    "Disable" : "Gera óvirkt",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Visit website" : "Heimsækja vefsvæðið",
    "Report a bug" : "Tilkynna um villu",
    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
    "Developer documentation" : "Skjölun fyrir þróunaraðila",
    "Show details for {appName} app" : "Birta ítarlegri upplýsingar fyrir {appName} forritið",
    "This app is supported via your current Nextcloud subscription." : "Þetta forrit er stutt í gegnum fyrirliggjandi Nextcloud-áskrift þína.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forrit í deiglunni eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
    "Featured" : "Í deiglunni",
    "Update to {update}" : "Uppfæra í {update}",
    "Rating: {score}/10" : "Einkunn: {score}/10",
    "All apps are up-to-date." : "Öll forrit eru af nýjustu útgáfu.",
    "Icon" : "Táknmynd",
    "Name" : "Heiti",
    "Version" : "Útgáfa",
    "Level" : "Stig",
    "Actions" : "Aðgerðir",
    "Results from other categories" : "Niðurstöður úr öðrum flokkum",
    "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
    "Disable all" : "Gera allt óvirkt",
    "Download and enable all" : "Sækja og virkja allt",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n forrit er með tiltæka uppfærslu","%n forrit eru með tiltæka uppfærslu"],
    "_Update_::_Update all_" : ["Uppfæra","Uppfæra allt"],
    "Device name" : "Heiti tækis",
    "Marked for remote wipe" : "Merkt fyrir fjartengda útþurrkun",
    "Device settings" : "Stillingar tækis",
    "Allow filesystem access" : "Leyfa aðgang að skráakerfi",
    "Rename" : "Endurnefna",
    "Revoke" : "Afturkalla",
    "Wipe device" : "Þurrka út af tæki",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Afturköllun á þessu teikni gæti komið í veg fyrir útþurrkun af tækinu nema ef útþurrkunin sé þegar byrjuð.",
    "Google Chrome for Android" : "Google Chrome fyrir Android",
    "{productName} iOS app" : "{productName} iOS-forrit",
    "{productName} Android app" : "{productName} Android-forrit",
    "{productName} Talk for iOS" : "{productName} Talk fyrir iOS",
    "{productName} Talk for Android" : "{productName} Talk fyrir Android",
    "This session" : "Þessa setu",
    "Device" : "Tæki",
    "Last activity" : "Síðasta virkni",
    "Devices & sessions" : "Tæki og setur",
    "Web, desktop and mobile clients currently logged in to your account." : "Veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
    "App name" : "Heiti forrits",
    "Create new app password" : "Búa til nýtt lykilorð forrits",
    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
    "Login" : "Innskráning",
    "Password" : "Lykilorð",
    "Show QR code for mobile apps" : "Birta QR-kóða fyrir snjallsímaforrit",
    "Could not copy app password. Please copy it manually." : "Tókst ekki að afrita lykilorð forritsins. Afritaðu það handvirkt.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Til að þjónninn virki sem skyldi, er mikilvægt að stilla bakgrunnsverk rétt. Mælt er með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "Last job execution ran {time}. Something seems wrong." : "Síðasta verk var keyrt {time}. Eitthvað er ekki eins og það á að sér að vera.",
    "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
    "Background job did not run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (mælt með þessu)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Nauðsynlegt er að hafa PHP-POSIX-viðaukann. Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
    "Unable to update background job mode" : "Tókst ekki að uppfæra ham bakgrunnsverks",
    "Profile" : "Notandasnið",
    "Enable" : "Virkja",
    "Unable to update profile default setting" : "Tókst ekki að uppfæra sjálfgefna stillingu notandasniðs",
    "Server-side encryption" : "Dulritun á þjóni",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Dulritun á vefþjóni (server-side encryption) gerir kleift að dulrita skrár sem sendar eru inn á þennan þjón. Sá eiginleiki er ekki án áhrifa á afköst kerfisins, þannig að slíkt ætti ekki að virkja nema að vel yfirlögðu máli.",
    "Enable server-side encryption" : "Virkja dulritun á þjóni",
    "Please read carefully before activating server-side encryption:" : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölin um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefin dulritunareining\" og keyrðu {command}",
    "Unable to update server side encryption config" : " Get ekki uppfært uppsetningu fyrir dulritun á þjóni",
    "Please confirm the group removal" : "Staðfestu fjarlægingu hópsins",
    "Cancel" : "Hætta við",
    "Confirm" : "Staðfesta",
    "Submit" : "Senda inn",
    "Rename group" : "Endurnefna hóp",
    "Remove group" : "Fjarlægja hóp",
    "Failed to remove group \"{group}\"" : "Mistókst að fjarlægja hópinn \"{group}\"",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Change password" : "Breyta lykilorði",
    "Your profile information" : "Persónuupplýsingar þínar",
    "Your profile picture" : "Auðkennismyndin þín",
    "Upload profile picture" : "Senda inn auðkennismynd",
    "Choose profile picture from Files" : "Veldu sem auðkennismynd úr skrám",
    "Remove profile picture" : "Fjarlægja auðkennismynd",
    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
    "Set as profile picture" : "Setja sem auðkennismynd",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Athugaðu að það getur tekið allt að 24 klukkustundir fyrir auðkennismyndina þína að uppfærast allsstaðar.",
    "Choose your profile picture" : "Veldu auðkennismynd fyrir þig",
    "Please select a valid png or jpg file" : "Veldu gilda PNG eða JPG-skrá",
    "Error setting profile picture" : "Villa kom upp við að setja auðkennismyndina",
    "Error cropping profile picture" : "Villa kom upp við að skera utan af auðkennismyndinni",
    "Error saving profile picture" : "Villa kom upp við að vista auðkennismyndina",
    "Error removing profile picture" : "Villa kom upp við að fjarlægja auðkennismyndina",
    "Your biography" : "Æviágrip þitt",
    "Details" : "Nánar",
    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
    "You are using <strong>{usage}</strong>" : "Þú ert að nota <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Þú ert að nota <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Fullt nafn þitt",
    "Back" : "Til baka",
    "This address is not confirmed" : "Þetta tölvupóstfang er ekki staðfest",
    "Primary email for password reset and notifications" : "Aðallykilorð fyrir tilkynningar og endurstillingu lykilorðs",
    "Email options" : "Tölvupóststillingar",
    "Remove primary email" : "Fjarlægja aðaltölvupóstfang",
    "Delete email" : "Eyða tölvupósti",
    "Unset as primary email" : "Aftengja sem aðaltölvupóstfang",
    "Set as primary email" : "Gera að aðaltölvupóstfangi",
    "Additional email address {index}" : "Aukalegt tölvupóstfang {index}",
    "Unable to delete primary email address" : "Get ekki eytt aðaltölvupóstfangi",
    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
    "Unable to add additional email address" : "Get ekki bætt við aukatölvupóstfangi",
    "Unable to update additional email address" : "Get ekki uppfært aukatölvupóstfang",
    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
    "No email address set" : "Ekkert tölvupóstfang sett",
    "Additional emails" : "Viðbótartölvupóstföng",
    "Your handle" : "Auðkennið þitt",
    "Your headline" : "Fyrirsögnin þín",
    "Languages" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "Unable to update language" : "Tókst ekki að uppfæra tungumál",
    "No language set" : "Ekkert tungumál skilgreint",
    "Week starts on {firstDayOfWeek}" : "Vika byrjar á {firstDayOfWeek}",
    "Unable to update locale" : "Tókst ekki að uppfæra staðfærslu",
    "No locale set" : "Engin staðfærsla tilgreind",
    "Your city" : "Borg/sveitarfélag",
    "Your organisation" : "Fyrirtækið þitt",
    "Your phone number" : "Símanúmerið þitt",
    "Edit your Profile visibility" : "Breyta sýnileika notandasniðsins þíns",
    "Unable to update profile enabled state" : "Tókst ekki að uppfæra virka stöðu notandasniðs",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Sú stilling sem meira er takmarkandi, annað hvort sýnileiki eða dreifing, fær meira vægi í notandasniðinu þínu. Til dæmis ef sýnileiki er stilltur á \"Birta öllum\" og dreifing er stillt á \"Einka\", þá hefur \"Einka\" meira vægi.",
    "Unable to update visibility of {displayId}" : "Tókst ekki að uppfæra sýnileika á {displayId}",
    "Your role" : "Hlutverk þitt",
    "Your X (formerly Twitter) handle" : "X (fyrrum Twitter) notandanafnið þitt",
    "Your website" : "Vefsvæðið þitt",
    "No {property} set" : "Ekkert {property} sett",
    "Unable to update {property}" : "Tókst ekki að uppfæra {property}",
    "Change scope level of {property}, current scope is {scope}" : "Breyta dreifingarstigi á {property}, fyrirliggjandi svið er {scope}",
    "Unable to update federation scope of the primary {property}" : "Tókst ekki að uppfæra skýjasambandsdreifingu á aðal {property}",
    "Unable to update federation scope of additional {property}" : "Tókst ekki að uppfæra skýjasambandsdreifingu á aukalegu {property}",
    "Add additional email" : "Bæta við aukatölvupóstfangi",
    "Add" : "Bæta við",
    "Create" : "Búa til",
    "Change" : "Breyta",
    "Delete" : "Eyða",
    "Reshare" : "Endurdeila",
    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
    "Default language" : "Sjálfgefið tungumál",
    "Common languages" : "Algeng tungumál",
    "Other languages" : "Önnur tungumál",
    "Password change is disabled because the master key is disabled" : "Lykilorðabreyting er óvirk vegna þess að aðallykill er óvirkur",
    "New user" : "Nýr notandi",
    "Display name" : "Birtingarnafn",
    "Either password or email is required" : "Annað hvort lykilorð eða tölvupóstfang eru nauðsynleg",
    "Password (required)" : "Lykilorð (nauðsynlegt)",
    "Email (required)" : "Tölvupóstfang (nauðsynlegt)",
    "Email" : "Netfang",
    "Groups (required)" : "Hópar (nauðsynlegt)",
    "Set user groups" : "Setja notendahópa",
    "Administered groups" : "Stýrðir hópar",
    "Set user as admin for …" : "Setja notanda sem stjórnanda fyrir …",
    "Quota" : "Kvóti",
    "Set user quota" : "Settu kvóta notandans",
    "Language" : "Tungumál",
    "Set default language" : "Settu sjálfgefið tungumál",
    "Manager" : "Stjórnandi",
    "Add new user" : "Bæta við nýjum notanda",
    "Set user manager" : "Settu stjórnanda notenda",
    "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
    "Username (required)" : "Notandanafn (nauðsynlegt)",
    "Total rows summary" : "Samantek á fjölda raða",
    "Loading users …" : "Hleð inn notendum …",
    "Scroll to load more rows" : "Skrunaðu til að hlaða inn fleiri röðum",
    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} notandi …","{userCount} notendur …"],
    "_{userCount} user_::_{userCount} users_" : ["{userCount} notandi","{userCount} notendur"],
    "Avatar" : "Auðkennismynd",
    "Username" : "Notandanafn",
    "Group admin for" : "Hópstjóri fyrir",
    "User backend" : "Bakendi notanda",
    "Storage location" : "Staðsetning gagnageymslu",
    "Last login" : "Síðasta innskráning",
    "User actions" : "Aðgerðir notanda",
    "Password or insufficient permissions message" : "Skilaboð um lykilorð eða ekki nægar heimildir",
    "Change display name" : "Breyta birtingarnafni",
    "Set new password" : "Stilla nýtt lykilorð",
    "Set new email address" : "Stilla nýtt tölvupóstfang",
    "Add user to group" : "Bæta notanda í hóp",
    "Set the language" : "Settu tungumálið",
    "{size} used" : "{size} notað",
    "Wipe all devices" : "Þurrka út af öllum tækjum",
    "Resend welcome email" : "Endursenda kveðjupóst",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
    "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
    "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
    "Wiped {userid}'s devices" : "Þurrkaði út af tækjum {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eyða að fullu notandaaðgangnum {userid}, þar með talið öllum persónulegum skrám viðkomandi, forritsgögnum, o.s.frv.",
    "Account deletion" : "Eyðing á aðgangi",
    "Delete {userid}'s account" : "Eyða notandaaðgangi {userid}",
    "Display name was successfully changed" : "Það tókst að breyta birtingarnafninu",
    "Password was successfully changed" : "Það tókst að breyta lykilorðinu",
    "Email was successfully changed" : "Það tókst að breyta tölvupóstfanginu",
    "Welcome mail sent!" : "Kveðjupóstur sendur!",
    "Done" : "Lokið",
    "Edit" : "Breyta",
    "Visibility" : "Sýnileiki",
    "Show language" : "Birta tungumál",
    "Show storage path" : "Birta slóð á gagnageymslu",
    "Show last login" : "Birta síðustu innskráningu",
    "Send email" : "Senda tölvupóst",
    "Defaults" : "Sjálfgefin gildi",
    "Default quota" : "Sjálfgefinn kvóti",
    "Select default quota" : "Setja sjálfgefinn kvóta",
    "Passwordless authentication requires a secure connection." : "Lykilorðalaus auðkenning krefst öruggrar tengingar.",
    "Add WebAuthn device" : "Bæta við WebAuthn-tæki",
    "Please authorize your WebAuthn device." : "Auðkenndu WebAuthn-tækið þitt.",
    "Name your device" : "Gefðu tækinu þínu nafn",
    "Adding your device …" : "Bæti við tækinu þínu …",
    "Server error while trying to add WebAuthn device" : "Villa á þjóni við að bæta við WebAuthn-tæki",
    "Server error while trying to complete WebAuthn device registration" : "Villa á þjóni við að ljúka skráningu WebAuthn-tækis",
    "Unnamed device" : "Nafnlaust tæki",
    "Passwordless Authentication" : "Lykilorðalaus auðkenning",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Settu aðganginn þinn upp fyrir lykilorðalausa auðkenningu byggða á FIDO2-staðlinum.",
    "No devices configured." : "Engin tæki skilgreind.",
    "The following devices are configured for your account:" : "Eftirfarandi tæki eru uppsett fyrir notandaaðganginn þinn:",
    "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
    "You need to enable the File sharing App." : "Þú verður að virkja skráardeilingarforritið.",
    "{license}-licensed" : "{license}-notkunarleyfi",
    "Changelog" : "Breytingaskrá",
    "by {author}\n{license}" : "frá {author}\n{license}",
    "Admins" : "Kerfisstjórar",
    "Disabled users" : "Óvirkir notendur",
    "Creating group …" : "Bý til hóp …",
    "Create group" : "Búa til hóp",
    "Group name" : "Heiti hóps",
    "Please enter a valid group name" : "Settu inn gilt nafn á hópi",
    "Failed to create group" : "Mistókst að búa til hóp",
    "Sending…" : "Sendi...",
    "Email sent" : "Tölvupóstur sendur",
    "Location" : "Staðsetning",
    "Profile picture" : "Einkennismynd",
    "About" : "Um hugbúnaðinn",
    "Full name" : "Fullt nafn",
    "Additional email" : "Aukatölvupóstfang",
    "Headline" : "Fyrirsögn",
    "Organisation" : "Stofnun/Félag/Fyrirtæki",
    "Phone number" : "Símanúmer",
    "Role" : "Role",
    "X (formerly Twitter)" : "X (fyrrum Twitter)",
    "Fediverse (e.g. Mastodon)" : "Skýjasamband - Fediverse (t.d. Mastodon)",
    "Website" : "Vefsvæði",
    "Profile visibility" : "Sýnileiki notandasniðs",
    "Locale" : "Staðfærsla",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Er ekki tiltækt þar sem þessi eiginleiki er nauðsynlegur fyrir kjarnavirkni á borð við skráadeilingu og boð í dagatölum",
    "Your apps" : "Forritin þín",
    "Active apps" : "Virk forrit",
    "Disabled apps" : "Óvirk forrit",
    "Updates" : "Uppfærslur",
    "App bundles" : "Forritavöndlar",
    "Featured apps" : "Forrit efst á baugi",
    "Supported apps" : "Studd forrit",
    "Show to everyone" : "Birta öllum",
    "Hide" : "Fela",
    "Download and enable" : "Sækja og virkja",
    "Allow untested app" : "Leyfa óprófuð forrit",
    "The app will be downloaded from the App Store" : "Forritið verður sótt úr forritabúðinni",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
    "Never" : "Aldrei",
    "Active users" : "Virkir notendur",
    "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Villa: Ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan",
    "Do you really want to wipe your data from this device?" : "Viltu í alvörunni hreinsa gögnin þín af þessu tæki?",
    "Confirm wipe" : "Staðfesta útþurrkun",
    "Error while wiping the device with the token" : "Villa við að hreinsa tækið með teikninu",
    "Error while updating device token name" : "Villa við að uppfæra nafn fyrir teikn tækisins",
    "Error while updating device token scope" : "Villa við að uppfæra gildissvið fyrir teikn tækisins",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
    "Account documentation" : "Hjálparskjöl fyrir notendaaðganga",
    "Administration documentation" : "Hjálparskjöl fyrir stjórnendur",
    "Documentation" : "Hjálparskjöl",
    "Forum" : "Vefspjall",
    "Nextcloud help resources" : "Aðstoðartilföng Nextcloud",
    "General documentation" : "Almenn hjálparskjöl",
    "None/STARTTLS" : "Ekkert/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Opna hjálparskjöl",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Það er mikilvægt að setja þennan vefþjón upp þannig að hann getir sent tölvupóst, eins og fyrir endurstillingu lykilorða og útsendingu tilkynninga.",
    "Send mode" : "Sendihamur",
    "Encryption" : "Dulritun",
    "Sendmail mode" : "Sendmail-hamur",
    "From address" : "Frá vistfangi",
    "Server address" : "Vistfang þjóns",
    "Port" : "Gátt",
    "Authentication" : "Auðkenning",
    "Authentication required" : "Auðkenningar krafist",
    "Credentials" : "Auðkenni",
    "SMTP Password" : "SMTP-lykilorð",
    "Save" : "Vista",
    "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "All checks passed." : "Stóðst allar prófanir.",
    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
    "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
    "Follow us on Mastodon" : "Fylgstu með okkur á Mastodon",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
    "No user supplied" : "Enginn notandi gefinn",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
    "Backend does not support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "PHP Opcache er ekki virkt. Fyrir betri afköst mælum við með að setja <code>opcache.enable=1</code> inn í PHP-uppsetninguna þína.",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Þú verður að gefa upp tölvupóstfangið þitt svo að þú getir sent prófunarpósta. Farðu á %s til þess.",
    "Invalid user" : "Ógildur notandi",
    "Your username is: %s" : "Notandanafnið þitt er: %s",
    "Logged in user must be a subadmin" : "Innskráður notandi verður að vera undirstjórnandi (subadmin)",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Fann ógild UUIDs á LDAP-notendum eða hópum. Yfirfarðu stillingar í \"Override UUID detection\" í Sérfræðinga/Expert hluta LDAP-uppsetningarinnar og notaðu \"occ ldap:update-uuid\" til að uppfæra þær.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Hægt er að þvinga fram tveggja-þrepa auðkenningu fyrir alla notendur og/eða tiltekna hópa. Ef þeir eru ekki með tveggja-þrepa auðkenningarþjónustu uppsetta, munu þeir ekki geta skráð sig inn á kerfið.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandi sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenningvirk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
    "Enable all" : "Virkja allt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Sync client - {os}" : "Samstilla biðlara - {os}",
    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
    "For security reasons this password will only be shown once." : "Af öryggisástæðum er þetta lykilorð einungis birt einu sinni.",
    "Copied!" : "Afritað!",
    "Copy" : "Afrita",
    "Execute one task with each page loaded. Use case: Single user instance." : "Framkvæma eitt verk með hverri innhlaðinni síðu. Dæmi um notkun: Tilvik fyrir einn notanda.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP. Dæmi um notkun: Mjög lítil tilvik (1–5 notendur eða eftir notkun).",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti. Mælt með þessu á öllum tilvikum.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"{user}\".",
    "Enable or disable profile by default for new users." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendur.",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn {group}. Notendunum verður EKKI eytt.",
    "Please confirm the group removal " : "Staðfestu fjarlægingu hópsins",
    "Choose profile picture from files" : "Veldu sem auðkennismynd úr skrám",
    "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
    "Your email address" : "Netfangið þitt",
    "Your location" : "Staðsetning þín",
    "Enable Profile" : "Virkja notandasnið",
    "Your Twitter handle" : "Twitter notandanafnið þitt",
    "You do not have permissions to see the details of this user" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notanda",
    "Add new password" : "Bæta við nýju lykilorði",
    "Add new email address" : "Bæta við nýju tölvupóstfangi",
    "Set user as admin for" : "Setja notanda sem stjórnanda fyrir",
    "Select user quota" : "Veldu kvóta notandans",
    "Toggle user actions menu" : "Víxla af/á valmynd fyrir aðgerðir notanda",
    "Delete user" : "Eyða notanda",
    "Disable user" : "Gera notanda óvirkan",
    "Enable user" : "Virkja notanda",
    "Edit User" : "Breyta notanda",
    "Will be autogenerated" : "Verður útbúið sjálfvirkt",
    "Add a new user" : "Bæta við nýjum notanda",
    "No users in here" : "Engir notendur hér",
    "Enter group name" : "Settu hér inn heiti á hópi",
    "Add group" : "Bæta við hópi",
    "Default quota:" : "Sjálfgefinn kvóti:",
    "Show Languages" : "Birta tungumál",
    "Show user backend" : "Birta bakenda notanda",
    "Send email to new user" : "Senda tölvupóst til nýs notanda",
    "Not saved" : "Ekki vistað",
    "Twitter" : "Twitter",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
    "Show to logged in users only" : "Birta einungis innskráðum notendum",
    "Enable untested app" : "Virkja óprófað forrit",
    "SMTP Username" : "SMTP-notandanafn",
    "Expire after" : "Rennur út eftir",
    "day(s)" : "dag(ar)",
    "Exclude groups from password requirements:" : "Undanskilja hópa frá kröfum um lykilorð:",
    "Set default expiration date" : "Setja sjálfgefinn gildistíma",
    "Exclude groups from creating link shares:" : "Undanskilja hópa frá því að búa til sameignartengla:",
    "Allow username autocompletion in share dialog" : "Leyfa sjálfklárun notandanafns í deilingarglugga",
    "Allow username autocompletion to users within the same groups" : "Leyfa sjálfklárun notandanafns á notendum innan sama hóps",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "Samstilling á DAV-nafnaskrá kerfisins hefur ekki enn verið keyrð, þar sem tilvikið þitt er með fleiri en 1000 notendur eða að villa hefur komið upp. Heyrðu samstillinguna handvirkt með því að kalla á occ dav:sync-system-addressbook.",
    "Edit display name" : "Breyta birtingarnafni",
    "Select manager" : "Veldu stýringu",
    "User's table" : "Tafla notandans",
    "Select user manager" : "Veldu notendastýringu",
    "Old user imported certificates" : "Gömul skilríki sem notandi hefur flutt inn",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "Í þetta kerfistilvik vantar ýmsar PHP-einingar sem mælt er með. Til að bæta afköst og betri samhæfni er mælt eindregið með að setja þær upp: %s.",
    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendunum verður EKKI eytt.",
    "No users" : "Engir notendur",
    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Listi yfir notendur. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendur munu birtast eftir því sem farið er í gegnum listann.",
    "Loading user …" : "Hleð inn notanda...",
    "Failed to update user manager" : "Mistókst að uppfæra notendastýringu",
    "User management settings" : "Stillingar notendastýringar",
    "Send welcome email to new users" : "Senda tölvupóst sem býður notanda velkominn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
